@@ -58,6 +58,17 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         if config.collector_address:
             self._init_ip_and_port(config.collector_address)
         self.buffer_size = config.buffer_size
+        self.type_dict = {"Entry": 0, "Exit": 1, "Local": 2}
+        self.layer_dict = {
+            "local": 0,
+            "database": 1,
+            "rpc_framework": 2,
+            "http": 3,
+            "mq": 4,
+            "cache": 5,
+            "log": 6,
+            "user": 7,
+        }
 
     def _init_ip_and_port(self, collector):
         """
@@ -118,8 +129,8 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         report_struct.trace_id = str(segment.related_traces[0])
         report_struct.parent_span_id = span.pid
         report_struct.span_id = span.sid
-        report_struct.span_type = span.kind.name
-        report_struct.span_layer = span.layer.name
+        report_struct.span_type = self.type_dict.get(span.kind.name, 3)
+        report_struct.span_layer = self.layer_dict.get(span.layer.name, 7)
         report_struct.start_time = span.start_time
         report_struct.end_time = span.end_time
         report_struct.duration = span.end_time - span.start_time
@@ -128,7 +139,10 @@ class UdpTraceSegmentReportService(TraceSegmentReportService):
         report_struct.peer = span.peer
         report_struct.is_error = span.error_occurred
         report_struct.tags = self.convert_tags(span.tags)
-        report_struct.logs = self.convert_logs(span.logs)
+        # logs 为空，统一不上报数据
+        logs = self.convert_logs(span.logs)
+        if logs:
+            report_struct.logs = self.convert_logs(span.logs)
         item = ReportStruct.convert(report_struct)
         functions.log("report_struct: %r", item, level=2)
         data = json.dumps(item).encode("utf-8")
